use geomag_wmm::initialise_magnetic_model;

fn main() {
    // Read path from command-line first argument
    let args: Vec<String> = std::env::args().collect();
    if args.len() != 2 {
        eprintln!("Usage: {} <path>", args[0]);
        std::process::exit(1);
    }
    let path = &args[1];

    let magnetic_model = initialise_magnetic_model(path);

    // Collecting user input
    println!("Height above WGS84 [metres]:");
    let mut height_above_wgs84 = String::new();
    std::io::stdin().read_line(&mut height_above_wgs84).expect("Failed to read line");
    let height_above_wgs84: f64 = height_above_wgs84.trim().parse().expect("Please type a number!");

    println!("Latitude [degrees]:");
    let mut latitude = String::new();
    std::io::stdin().read_line(&mut latitude).expect("Failed to read line");
    let latitude: f64 = latitude.trim().parse().expect("Please type a number!");

    println!("Longitude [degrees]:");
    let mut longitude = String::new();
    std::io::stdin().read_line(&mut longitude).expect("Failed to read line");
    let longitude: f64 = longitude.trim().parse().expect("Please type a number!");

    println!("Date [YYYY-MM-DD|YYYY.decimal]:");
    let mut date = String::new();
    let mut decimal_year = 0.0;
    std::io::stdin().read_line(&mut date).expect("Failed to read line");
    if date.contains('-') {
        let date: Vec<&str> = date.trim().split("-").collect();
        let year: f64 = date[0].parse().expect("Please type a number!");
        let month: f64 = date[1].parse().expect("Please type a number!");
        let day: f64 = date[2].parse().expect("Please type a number!");
        decimal_year = year + (month - 1.0) / 12.0 + (day - 1.0) / 365.25;
    }
    else if date.contains('.') {
        decimal_year = date.trim().parse().expect("Please type a number!");
    }
    else {
        eprintln!("Please type a valid date format! (YYYY-MM-DD or YYYY.decimal)");
        std::process::exit(1);
    }


    // Calculating

    let result = magnetic_model.calculate(height_above_wgs84, latitude, longitude, decimal_year);

    match result {
        Ok(results) => {
            println!("Results:");
            println!("X: {:?} nT", results.0);
            println!("Y: {:?} nT", results.1);
            println!("Z: {:?} nT", results.2);
            println!("H: {:?} nT", results.3);
            println!("F: {:?} nT", results.4);
            println!("I: {:?} degrees", results.5);
            println!("D: {:?} degrees", results.6);
            println!("X_dot: {:?} nT/year", results.7);
            println!("Y_dot: {:?} nT/year", results.8);
            println!("Z_dot: {:?} nT/year", results.9);
            println!("H_dot: {:?} nT/year", results.10);
            println!("F_dot: {:?} nT/year", results.11);
            println!("I_dot: {:?} degrees/year", results.12);
            println!("D_dot: {:?} degrees/year", results.13);
        },
        Err(e) => {
            eprintln!("Error: {}", e);
            std::process::exit(1);
        }
    }
}